@@ -1,24 +1,25 @@
 package Proc::tored::PidFile;
 # ABSTRACT: Manage a service using a pid file
-$Proc::tored::PidFile::VERSION = '0.13';
+$Proc::tored::PidFile::VERSION = '0.14';
 
 use warnings;
 use strict;
+use Moo;
 use Carp;
 use Fcntl qw(:flock :seek :DEFAULT);
 use Guard qw(guard);
 use Path::Tiny qw(path);
 use Time::HiRes qw(sleep);
 use Try::Tiny;
+use Types::Standard -types;
 
+has file_path => (is => 'ro', isa => Str);
 
-sub new {
-  my ($class, $file_path) = @_;
-  bless {
-    file => path($file_path),
-    write_lock => path("$file_path.lock"),
-  }, $class;
-}
+has file => (is => 'lazy', isa => InstanceOf['Path::Tiny']);
+sub _build_file { path(shift->file_path) }
+
+has write_lock_file => (is => 'lazy', isa => InstanceOf['Path::Tiny']);
+sub _build_write_lock_file { path(shift->file_path . '.lock') }
 
 
 sub is_running {
@@ -38,8 +39,8 @@ sub running_pid {
 
 sub read_file {
   my $self = shift;
-  return 0 unless $self->{file}->is_file;
-  my ($line) = $self->{file}->lines({count => 1, chomp => 1}) or return 0;
+  return 0 unless $self->file->is_file;
+  my ($line) = $self->file->lines({count => 1, chomp => 1}) or return 0;
   my ($pid) = $line =~ /^(\d+)$/;
   return $pid || 0;
 }
@@ -49,7 +50,7 @@ sub write_file {
   my $self = shift;
   my $lock = $self->write_lock or return 0;
   return 0 if $self->running_pid;
-  $self->{file}->spew("$$\n");
+  $self->file->spew("$$\n");
   return 1;
 }
 
@@ -58,8 +59,8 @@ sub clear_file {
   my $self = shift;
   my $lock = $self->write_lock or return;
   return unless $self->is_running;
-  $self->{file}->append({truncate => 1});
-  try { $self->{file}->remove }
+  $self->file->append({truncate => 1});
+  try { $self->file->remove }
   catch { warn "error unlinking pid file: $_" }
 }
 
@@ -78,7 +79,7 @@ sub write_lock {
   my $self = shift;
 
   # Existing .lock file means another process came in ahead
-  my $lock = $self->{write_lock};
+  my $lock = $self->write_lock_file;
   return if $lock->exists;
 
   my $locked = try {
@@ -115,7 +116,7 @@ Proc::tored::PidFile - Manage a service using a pid file
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -137,11 +138,6 @@ Allows the use of a pid file to manage a running service.
 
 =head1 METHODS
 
-=head2 new
-
-Creates a new pid file. Accepts a string indicating the path to be used as a
-pid file.
-
 =head2 is_running
 
 Returns true if the pid indicated by the pid file is the current process.
